def format_sentence(sentence: str) -> str:
    """
    Нерадивый ученик
    Ученик написал на доске предложение:
    'привет, мир. какая хорошая погода. мне все нравится.'
    Но он забыл, что предложения начинаются с большой буквы.
    Напишите функцию, которая принимает строку с таким предложением и возвращает новую строку, где все предложения начинаются с большой буквы.
    Считаем, что предложение может заканчиваться точкой.
    """
    return ""


assert format_sentence("") == ""
assert format_sentence("Привет.") == "Привет."

assert format_sentence(
    "анализ данных - лучшая профессия."
) == "Анализ данных - лучшая профессия."

assert format_sentence(
    "привет, мир. какая хорошая погода. мне все нравится."
) == "Привет, мир. Какая хорошая погода. Мне все нравится."


def make_abbreviation(entity: str) -> str:
    """
    Аббревиатура
    Напишите функцию, которая принимает название учреждения и возвращает аббревиатуру.
    Например, Министерство Иностранных Дел -> МИД
    или Российская Федерация -> РФ
    Нельзя привязываться к числу слов, их может быть бесконечное число.
    Буквы в entity могут быть как большими, так и маленькими.
    Если в entity одно слово, то вернуть его первую букву, например:
    'учреждение' 
    """
    return ""


assert make_abbreviation("") == ""
assert make_abbreviation("учреждение") == "У"
assert make_abbreviation("Российская Федерация") == "РФ"
assert make_abbreviation("министерство иностранных дел") == "МИД"
assert make_abbreviation(
    "союз   советских   социалистических  республик") == "СССР"


def get_local_maximums(lst: list[int]) -> list[int]:
    """
    Локальные максимумы
    Напишите функцию, которая принимает список и возвращает список локальных максимумов.
    Локальный максимум - это элемент, который:
    - больше предыдущего
    - больше следующего

    Например: 
     - [1,2,5,3,4,7,8,3,2,0] -> [5, 8]
     - [3,2,1] -> [] пустой список, не лок. максимумов.

    """
    return []


assert get_local_maximums([8, 7, 6, 5, 4]) == []
assert get_local_maximums([8, 10, 6, 5, 4]) == [10]
assert get_local_maximums([1, 4, 2, 5, 10, 3, 2]) == [4, 10]
assert get_local_maximums([1, 2, 5, 3, 4, 7, 8, 3, 2, 0]) == [5, 8]


def sum_positive(lst: list[int]) -> int:
    """
    Сумма положительных
    Написать функцию, которая принимает список чисел и вернет сумму только положительных элементов.
    Для пустого списка вернуть 0. Аналогично, вернуть 0 если нет ни одного положительного элемента.
    Например:
    - solution([]) -> 0
    - solution([1, 2, -3]) -> 3
    - solution([3, 4, -2, 7, -10, 12]) -> 26
    """
    return 0


assert sum_positive([]) == 0
assert sum_positive([14]) == 14
assert sum_positive([2, 5, 8]) == 15
assert sum_positive([3, -2, -2, -15, -10, 12]) == 15
assert sum_positive([1, 2, -3]) == 3
assert sum_positive([3, 4, -2, 7, -10, 12]) == 26
assert sum_positive([-3, -4, -2, -7, -10, -12]) == 0



from typing import Callable
from analyst_klondike.features.message_box.ui.mb_screen import MessageBoxScreen
from analyst_klondike.state.app_state import AppState


def show_message(message: str, on_close: Callable[[AppState | None], None] | None = None) -> None:
    # pylint: disable=import-outside-toplevel
    from analyst_klondike.ui.runner_app import get_app

    app = get_app()
    app.push_screen(MessageBoxScreen(message=message), on_close)


def hide_message_box():
    # pylint: disable=import-outside-toplevel
    from analyst_klondike.ui.runner_app import get_app

    app = get_app()

    last_screen = app.screen_stack[-1]
    if isinstance(last_screen, MessageBoxScreen):
        app.pop_screen()



import sys
from analyst_klondike.features.data_context.arg_file_load.arg_load import (
    TooManyArgumentsException,
    process_args
)
from analyst_klondike.ui.runner_app import get_app


def analyst_klondike():
    try:
        app = get_app()
        process_args(sys.argv)
        app.run()
    except (FileNotFoundError, TooManyArgumentsException):
        exc_type, exc_value, exc_traceback = sys.exc_info()
        print(f"Exception type: {exc_type}")
        print(f"Exception value: {exc_value}")
        print(f"Traceback object: {exc_traceback}")


if __name__ == "__main__":
    analyst_klondike()



def get_palindroms(words: list[str]) -> list[list[str] | str]:
    """
        Группировка палиндромов
        Написать функцию, которая группирует слова-палиндромы вместе.
        Например для списка слов ['eat','tea','the','teh','hte','abc','edf'] функция должна вернуть
        [['eat','tea'], ['the','teh','hte'], 'abc','edf'].
        Два слова являются палиндромами если они состоят из одних и тех же букв, но в разном порядке.
    """
    return []


assert get_palindroms(['eat', 'tea', 'the', 'teh', 'hte', 'abc', 'edf']) == [
    ['eat', 'tea'], ['the', 'teh', 'hte'], 'abc', 'edf']


def get_substrings(subs: str, long_string: str) -> list[int]:
    """
        Поиск подстрок
        Написать функцию, которая принимает строку subs и строку long_string.
        Функция вернет список индексов всех вхождений подстроки subs в строке long_string. 
        Номера позиций начинаются с нуля.
        Например:
         - подстрока "hello" встречается в строке "hello, world, all people hello" два раза: на позиции 0 (начало строки) и 25.
         - подстрока "xyz" встречается в строке "abc def xyz ghr" один раз на позиции 8.
        Таким образом:
         - solution("hello, world, all people hello") -> [0, 25]
         - solution("xyz", "abc def xyz ghr") -> [8]
         - solution("", "my string") -> [] (для пустой строки вернет пустой список)
         - solution("hello", "ok, great!") -> [] (нет вхождений)
    """
    return []


assert get_substrings("abc", "_abc_abc") == [1, 5]
assert get_substrings("hello", "hello world hello") == [0, 12]
assert get_substrings("xyz", "abc def xyz ghr") == [8]
